@@ -107,31 +107,8 @@ var _ = Describe("(Integration) [EKS Addons test]", func() {
 				return cmd
 			}, "5m", "30s").Should(RunSuccessfullyWithOutputStringLines(ContainElement(ContainSubstring("ACTIVE"))))
 
-			By("successfully creating the kube-proxy addon")
-			cmd := params.EksctlCreateCmd.
-				WithArgs(
-					"addon",
-					"--name", "kube-proxy",
-					"--cluster", clusterName,
-					"--force",
-					"--wait",
-					"--verbose", "2",
-				)
-			Expect(cmd).To(RunSuccessfully())
-
-			Eventually(func() runner.Cmd {
-				cmd := params.EksctlGetCmd.
-					WithArgs(
-						"addon",
-						"--name", "kube-proxy",
-						"--cluster", clusterName,
-						"--verbose", "2",
-					)
-				return cmd
-			}, "5m", "30s").Should(RunSuccessfullyWithOutputStringLines(ContainElement(ContainSubstring("ACTIVE"))))
-
 			By("Deleting the kube-proxy addon")
-			cmd = params.EksctlDeleteCmd.
+			cmd := params.EksctlDeleteCmd.
 				WithArgs(
 					"addon",
 					"--name", "kube-proxy",
@@ -155,12 +132,45 @@ var _ = Describe("(Integration) [EKS Addons test]", func() {
 		})
 
 		It("should have full control over configMap when creating addons", func() {
-			var (
-				clusterConfig *api.ClusterConfig
-				configMap     *corev1.ConfigMap
-			)
+			clusterConfig := getInitialClusterConfig()
+			clusterConfig.Addons = []*api.Addon{
+				{
+					Name:    "coredns",
+					Version: "latest",
+				},
+			}
+			cmd := params.EksctlCreateCmd.
+				WithArgs(
+					"addon",
+					"--config-file", "-",
+				).
+				WithoutArg("--region", params.Region).
+				WithStdin(clusterutils.Reader(clusterConfig))
+			Expect(cmd).To(RunSuccessfully())
 
-			configMap = getConfigMap(rawClient.ClientSet(), "coredns")
+			By("deleting coredns but preserving its resources")
+			cmd = params.EksctlDeleteCmd.
+				WithArgs(
+					"addon",
+					"--cluster", clusterConfig.Metadata.Name,
+					"--name", "coredns",
+					"--verbose", "4",
+					"--preserve",
+					"--region", params.Region,
+				)
+			Expect(cmd).To(RunSuccessfully())
+
+			Eventually(func() runner.Cmd {
+				return params.EksctlGetCmd.
+					WithArgs(
+						"addon",
+						"--name", "coredns",
+						"--cluster", clusterName,
+						"--verbose", "4",
+					)
+			}, "5m", "30s").ShouldNot(RunSuccessfully())
+
+			configMap := getConfigMap(rawClient.ClientSet(), "coredns")
 			oldCacheValue := getCacheValue(configMap)
 			newCacheValue := addToString(oldCacheValue, 5)
 			updateCacheValue(configMap, oldCacheValue, newCacheValue)
@@ -178,14 +188,14 @@ var _ = Describe("(Integration) [EKS Addons test]", func() {
 			data, err := json.Marshal(clusterConfig)
 			Expect(err).NotTo(HaveOccurred())
 
-			cmd := params.EksctlCreateCmd.
+			cmd = params.EksctlCreateCmd.
 				WithArgs(
 					"addon",
 					"--config-file", "-",
 				).
 				WithoutArg("--region", params.Region).
 				WithStdin(bytes.NewReader(data))
-			Expect(cmd).ShouldNot(RunSuccessfully())
+			Expect(cmd).NotTo(RunSuccessfully())
 
 			Eventually(func() runner.Cmd {
 				cmd := params.EksctlGetCmd.
@@ -866,7 +876,11 @@ func getInitialClusterConfig() *api.ClusterConfig {
 			Name:             "vpc-cni",
 			AttachPolicyARNs: []string{"arn:aws:iam::aws:policy/AmazonEKS_CNI_Policy"},
 		},
+		{
+			Name: "kube-proxy",
+		},
 	}
+	clusterConfig.AddonsConfig.DisableDefaultAddons = true
 
 	ng := &api.ManagedNodeGroup{
 		NodeGroupBase: &api.NodeGroupBase{
