@@ -4,34 +4,28 @@ import (
 	"context"
 	"fmt"
 	"strings"
-	"time"
 
 	"github.com/aws/aws-sdk-go-v2/aws"
 	"github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs"
 
-	"github.com/weaveworks/eksctl/pkg/actions/iamidentitymapping"
-	"github.com/weaveworks/eksctl/pkg/actions/identityproviders"
-
 	"github.com/weaveworks/eksctl/pkg/windows"
 
 	"github.com/kris-nova/logger"
 	"github.com/pkg/errors"
-	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
-	"k8s.io/apimachinery/pkg/runtime"
-	"k8s.io/apimachinery/pkg/types"
+
 	"k8s.io/apimachinery/pkg/util/sets"
 
+	"github.com/weaveworks/eksctl/pkg/actions/iamidentitymapping"
+	"github.com/weaveworks/eksctl/pkg/actions/identityproviders"
 	"github.com/weaveworks/eksctl/pkg/actions/irsa"
 	"github.com/weaveworks/eksctl/pkg/addons"
+	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
 	"github.com/weaveworks/eksctl/pkg/cfn/manager"
 	"github.com/weaveworks/eksctl/pkg/fargate"
 	iamoidc "github.com/weaveworks/eksctl/pkg/iam/oidc"
+	"github.com/weaveworks/eksctl/pkg/kubernetes"
 	instanceutils "github.com/weaveworks/eksctl/pkg/utils/instance"
 	"github.com/weaveworks/eksctl/pkg/utils/tasks"
-
-	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
-	"github.com/weaveworks/eksctl/pkg/kubernetes"
 )
 
 type clusterConfigTask struct {
@@ -184,48 +178,12 @@ func newEFADevicePluginTask(
 	return &t
 }
 
-type restartDaemonsetTask struct {
-	name            string
-	namespace       string
-	clusterProvider *ClusterProvider
-	spec            *api.ClusterConfig
-}
-
-func (t *restartDaemonsetTask) Describe() string {
-	return fmt.Sprintf(`restart daemonset "%s/%s"`, t.namespace, t.name)
-}
-
-func (t *restartDaemonsetTask) Do(errCh chan error) error {
-	defer close(errCh)
-	clientSet, err := t.clusterProvider.NewStdClientSet(t.spec)
-	if err != nil {
-		return err
-	}
-	ds := clientSet.AppsV1().DaemonSets(t.namespace)
-	dep, err := ds.Get(context.TODO(), t.name, metav1.GetOptions{})
-	if err != nil {
-		return err
-	}
-	if dep.Spec.Template.Annotations == nil {
-		dep.Spec.Template.Annotations = make(map[string]string)
-	}
-	dep.Spec.Template.Annotations["eksctl.io/restartedAt"] = time.Now().Format(time.RFC3339)
-	bytes, err := runtime.Encode(unstructured.UnstructuredJSONScheme, dep)
-	if err != nil {
-		return errors.Wrapf(err, "failed to marshal %q deployment", t.name)
-	}
-	if _, err := ds.Patch(context.TODO(), t.name, types.MergePatchType, bytes, metav1.PatchOptions{}); err != nil {
-		return errors.Wrap(err, "failed to patch deployment")
-	}
-	logger.Info(`daemonset "%s/%s" restarted`, t.namespace, t.name)
-	return nil
-}
-
 // CreateExtraClusterConfigTasks returns all tasks for updating cluster configuration
-func (c *ClusterProvider) CreateExtraClusterConfigTasks(ctx context.Context, cfg *api.ClusterConfig) *tasks.TaskTree {
+func (c *ClusterProvider) CreateExtraClusterConfigTasks(ctx context.Context, cfg *api.ClusterConfig, preNodeGroupAddons *tasks.TaskTree, updateVPCCNITask *tasks.GenericTask) *tasks.TaskTree {
 	newTasks := &tasks.TaskTree{
 		Parallel:  false,
 		IsSubTask: true,
+		Tasks:     []tasks.Task{preNodeGroupAddons},
 	}
 
 	newTasks.Append(&tasks.GenericTask{
@@ -245,6 +203,13 @@ func (c *ClusterProvider) CreateExtraClusterConfigTasks(ctx context.Context, cfg
 		},
 	})
 
+	if api.IsEnabled(cfg.IAM.WithOIDC) {
+		c.appendCreateTasksForIAMServiceAccounts(ctx, cfg, newTasks)
+		if updateVPCCNITask != nil {
+			newTasks.Append(updateVPCCNITask)
+		}
+	}
+
 	if cfg.HasClusterCloudWatchLogging() {
 		if logRetentionDays := cfg.CloudWatch.ClusterLogging.LogRetentionInDays; logRetentionDays != 0 {
 			newTasks.Append(&clusterConfigTask{
@@ -277,10 +242,6 @@ func (c *ClusterProvider) CreateExtraClusterConfigTasks(ctx context.Context, cfg
 		})
 	}
 
-	if api.IsEnabled(cfg.IAM.WithOIDC) {
-		c.appendCreateTasksForIAMServiceAccounts(ctx, cfg, newTasks)
-	}
-
 	if len(cfg.IdentityProviders) > 0 {
 		newTasks.Append(identityproviders.NewAssociateProvidersTask(ctx, *cfg.Metadata, cfg.IdentityProviders, c.AWSProvider.EKS()))
 	}
@@ -458,16 +419,10 @@ func (c *ClusterProvider) appendCreateTasksForIAMServiceAccounts(ctx context.Con
 	// given a clientSet getter and OpenIDConnectManager reference we can build out
 	// the list of tasks for each of the service accounts that need to be created
 	newTasks := c.NewStackManager(cfg).NewTasksToCreateIAMServiceAccounts(
-		api.IAMServiceAccountsWithImplicitServiceAccounts(cfg),
+		cfg.IAM.ServiceAccounts,
 		oidcPlaceholder,
 		clientSet,
 	)
 	newTasks.IsSubTask = true
 	tasks.Append(newTasks)
-	tasks.Append(&restartDaemonsetTask{
-		namespace:       "kube-system",
-		name:            "aws-node",
-		clusterProvider: c,
-		spec:            cfg,
-	})
 }
